@@ -32,7 +32,7 @@ void Key::setFingerIndex(int finger)
     if(finger != m_fingerIndex)
     {
         m_fingerIndex = finger;
-        emit fingerIndexChanged();
+        Q_EMIT fingerIndexChanged();
     }
 }
 
@@ -46,7 +46,7 @@ void Key::setHasHapticMarker(bool hasHapticMarker)
     if(hasHapticMarker != m_hasHapticMarker)
     {
         m_hasHapticMarker = hasHapticMarker;
-        emit hasHapticMarkerChanged();
+        Q_EMIT hasHapticMarkerChanged();
     }
 }
 
@@ -68,31 +68,31 @@ KeyChar* Key::keyChar(int index) const
 
 void Key::addKeyChar(KeyChar* keyChar)
 {
-    emit keyCharAboutToBeAdded(keyChar, m_keyChars.length());
+    Q_EMIT keyCharAboutToBeAdded(keyChar, m_keyChars.length());
     m_keyChars.append(keyChar);
     keyChar->setParent(this);
-    emit keyCharCountChanged();
-    emit keyCharAdded();
+    Q_EMIT keyCharCountChanged();
+    Q_EMIT keyCharAdded();
 }
 
 void Key::insertKeyChar(int index, KeyChar* keyChar)
 {
     Q_ASSERT(index >= 0 && index < m_keyChars.length());
-    emit keyCharAboutToBeAdded(keyChar, index);
+    Q_EMIT keyCharAboutToBeAdded(keyChar, index);
     m_keyChars.insert(index, keyChar);
     keyChar->setParent(this);
-    emit keyCharCountChanged();
-    emit keyCharAdded();
+    Q_EMIT keyCharCountChanged();
+    Q_EMIT keyCharAdded();
 }
 
 void Key::removeKeyChar(int index)
 {
     Q_ASSERT(index >= 0 && index < m_keyChars.length());
-    emit keyCharsAboutToBeRemoved(index, index);
+    Q_EMIT keyCharsAboutToBeRemoved(index, index);
     delete m_keyChars.at(index);
     m_keyChars.removeAt(index);
-    emit keyCharCountChanged();
-    emit keyCharsRemoved();
+    Q_EMIT keyCharCountChanged();
+    Q_EMIT keyCharsRemoved();
 }
 
 void Key::clearKeyChars()
@@ -100,11 +100,11 @@ void Key::clearKeyChars()
     if (m_keyChars.isEmpty())
         return;
 
-    emit keyCharsAboutToBeRemoved(0, m_keyChars.length() - 1);
+    Q_EMIT keyCharsAboutToBeRemoved(0, m_keyChars.length() - 1);
     qDeleteAll(m_keyChars);
     m_keyChars.clear();
-    emit keyCharCountChanged();
-    emit keyCharsRemoved();
+    Q_EMIT keyCharCountChanged();
+    Q_EMIT keyCharsRemoved();
 }
 
 void Key::copyFrom(Key* source)
